@@ -37,8 +37,7 @@ public:
     QStringList mBcc;
 };
 
-AddressAttribute::AddressAttribute(const QString &from, const QStringList &to,
-                                   const QStringList &cc, const QStringList &bcc)
+AddressAttribute::AddressAttribute(const QString &from, const QStringList &to, const QStringList &cc, const QStringList &bcc)
     : d(new Private)
 {
     d->mFrom = from;
@@ -126,9 +125,7 @@ void AddressAttribute::setBcc(const QStringList &bcc)
 }
 
 // Register the attribute when the library is loaded.
-namespace
-{
-
+namespace {
 bool address_dummy()
 {
     using namespace Akonadi;
@@ -137,5 +134,4 @@ bool address_dummy()
 }
 
 const bool address_registered = address_dummy();
-
 }
